awsmate
=======

.. toctree::
   :maxdepth: 3
   :caption: Overview

   readme
   changelog
   example_application

.. toctree::
   :maxdepth: 4
   :caption: API reference

   awsmate
   apigateway
   eventbridge
   lambdafunction
   s3
   logger

.. toctree::
   :maxdepth: 2
   :caption: Technical appendix

   genindex
   testing
   release_process

.. toctree::
   :maxdepth: 2
   :caption: Community

   contributing
   code_of_conduct   

.. sidebar-links::
   :github:
   :pypi: awsmate
